@@ -26,11 +26,11 @@ Then, in your Dancer2 PSGI startup script:
 
 =head1 VERSION
 
-Version 0.08
+Version 0.09
 
 =cut
 
-our $VERSION = '0.08';
+our $VERSION = '0.09';
 
 use strict;
 use warnings;
@@ -312,7 +312,7 @@ sub _load_widgets {
 
         $elements = $widget->elements;
 
-        if (scalar(@$elements)) {
+       # if (scalar(@$elements)) {
             push @widgets, { 
                 id => $id++,
                 name => $w->{name}, 
@@ -320,8 +320,10 @@ sub _load_widgets {
                 view => $w->{name}.'.tt',
                 instance => $widget,
                 elements => $elements,
+                has_elements => scalar(@$elements),
+                css => $widget->css,
             };
-        }
+        #}
     }
     return \@widgets;
 }
